from setuptools import setup

setup(
    name='morse-py3',
    version='1.0',
    packages=['morse-py3'],
    install_requires=None,
    author='Benjamin Nicholls',
    author_email='benn.andrews2022@gmail.com',
    description='A simple CLI tool to take any text and '
                'convert it into morse code.'
)
